Class: RGL::DOT::Port
- Inherits:
-
Object
- Object
- RGL::DOT::Port
- Defined in:
- lib/rgl/rdot.rb
Overview
Ports are used when a Node instance has its ‘shape’ option set to record or Mrecord. Ports can be nested.
Instance Attribute Summary collapse
-
#label ⇒ Object
Returns the value of attribute label.
-
#name ⇒ Object
Returns the value of attribute name.
-
#ports ⇒ Object
Returns the value of attribute ports.
Instance Method Summary collapse
-
#initialize(name_or_ports = nil, label = nil) ⇒ Port
constructor
Create a new port with either an optional name and label or a set of nested ports.
-
#to_s ⇒ Object
Returns a string representation of this port.
Constructor Details
#initialize(name_or_ports = nil, label = nil) ⇒ Port
Create a new port with either an optional name and label or a set of nested ports.
:call-seq:
new(name = nil, label = nil)
new(ports)
A nil value for name is valid; otherwise, it must be a String or it will be interpreted as ports.
266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/rgl/rdot.rb', line 266 def initialize(name_or_ports = nil, label = nil) if name_or_ports.nil? || name_or_ports.kind_of?(String) @name = name_or_ports @label = label @ports = nil else @ports = name_or_ports @name = nil @label = nil end end |
Instance Attribute Details
#label ⇒ Object
Returns the value of attribute label.
254 255 256 |
# File 'lib/rgl/rdot.rb', line 254 def label @label end |
#name ⇒ Object
Returns the value of attribute name.
254 255 256 |
# File 'lib/rgl/rdot.rb', line 254 def name @name end |
#ports ⇒ Object
Returns the value of attribute ports.
254 255 256 |
# File 'lib/rgl/rdot.rb', line 254 def ports @ports end |
Instance Method Details
#to_s ⇒ Object
Returns a string representation of this port. If ports is a non-empty Enumerable, a nested ports representation is returned; otherwise, a name-label representation is returned.
282 283 284 285 286 287 288 289 |
# File 'lib/rgl/rdot.rb', line 282 def to_s if @ports.nil? || @ports.empty? n = (name.nil? || name.empty?) ? '' : "<#{name}>" n + ((n.empty? || label.nil? || label.empty?) ? '' : ' ') + label.to_s else '{' + @ports.collect { |p| p.to_s }.join(' | ') + '}' end end |