Class: RGL::Edge::DirectedEdge
- Inherits:
-
Object
- Object
- RGL::Edge::DirectedEdge
- Defined in:
- lib/rgl/base.rb
Overview
An RGL::Edge is simply a directed pair (source -> target). Most library functions try do omit to instantiate edges. They instead use two vertex parameters for representing edges (see Graph#each_edge). If a client wants to store edges explicitly DirectedEdge or UnDirectedEdge instances are returned (i.e. Graph#edges).
Direct Known Subclasses
Instance Attribute Summary collapse
-
#source ⇒ Object
Returns the value of attribute source.
-
#target ⇒ Object
Returns the value of attribute target.
Class Method Summary collapse
-
.[](*a) ⇒ Object
Can be used to create an edge from a two element array.
Instance Method Summary collapse
-
#<=>(e) ⇒ Object
Sort support is dispatched to the <=> method of Array.
-
#[](index) ⇒ Object
Edges can be indexed.
-
#eql?(edge) ⇒ Boolean
(also: #==)
Two directed edges (u,v) and (x,y) are equal iff u == x and v == y.
- #hash ⇒ Object
-
#initialize(a, b) ⇒ DirectedEdge
constructor
Create a new DirectedEdge with source
aand targetb. -
#reverse ⇒ Edge
Returns (v,u) if self == (u,v).
-
#to_a ⇒ Array
Returns the array [source,target].
-
#to_s ⇒ String
(also: #inspect)
Returns string representation of the edge.
Constructor Details
#initialize(a, b) ⇒ DirectedEdge
Create a new DirectedEdge with source a and target b.
47 48 49 |
# File 'lib/rgl/base.rb', line 47 def initialize(a, b) @source, @target = a, b end |
Instance Attribute Details
#source ⇒ Object
Returns the value of attribute source.
38 39 40 |
# File 'lib/rgl/base.rb', line 38 def source @source end |
#target ⇒ Object
Returns the value of attribute target.
38 39 40 |
# File 'lib/rgl/base.rb', line 38 def target @target end |
Class Method Details
.[](*a) ⇒ Object
Can be used to create an edge from a two element array.
41 42 43 |
# File 'lib/rgl/base.rb', line 41 def self.[](*a) new(a[0], a[1]) end |
Instance Method Details
#<=>(e) ⇒ Object
Sort support is dispatched to the <=> method of Array
95 96 97 |
# File 'lib/rgl/base.rb', line 95 def <=> e self.to_a <=> e.to_a end |
#[](index) ⇒ Object
Edges can be indexed. edge.at(0) == edge.source, edge.at(n) == edge.target for all n>0. Edges can thus be used as a two element array.
72 73 74 |
# File 'lib/rgl/base.rb', line 72 def [](index) index.zero? ? source : target end |
#eql?(edge) ⇒ Boolean Also known as: ==
Two directed edges (u,v) and (x,y) are equal iff u == x and v == y. eql? is needed when edges are inserted into a Set. eql? is aliased to ==.
53 54 55 |
# File 'lib/rgl/base.rb', line 53 def eql?(edge) (source == edge.source) && (target == edge.target) end |
#hash ⇒ Object
59 60 61 |
# File 'lib/rgl/base.rb', line 59 def hash source.hash ^ target.hash end |
#reverse ⇒ Edge
Returns (v,u) if self == (u,v).
65 66 67 |
# File 'lib/rgl/base.rb', line 65 def reverse self.class.new(target, source) end |
#to_a ⇒ Array
Returns the array [source,target].
89 90 91 |
# File 'lib/rgl/base.rb', line 89 def to_a [source, target] end |
#to_s ⇒ String Also known as: inspect
Returns string representation of the edge
80 81 82 |
# File 'lib/rgl/base.rb', line 80 def to_s "(#{source}-#{target})" end |