Module: RGL::GraphIterator
- Includes:
- GraphWrapper, Stream
- Included in:
- BFSIterator, TopsortIterator
- Defined in:
- lib/rgl/graph_iterator.rb
Overview
A GraphIterator is the abstract basis for all Iterators on graphs. Each graph iterator should implement the protocol defined in module Stream.
Instance Attribute Summary
Attributes included from GraphWrapper
Instance Method Summary collapse
Methods included from GraphWrapper
Instance Method Details
#length ⇒ int
18 19 20 |
# File 'lib/rgl/graph_iterator.rb', line 18 def length inject(0) { |sum| sum + 1 } end |